<?php

/*
 * The MIT License
 *
 * Copyright (c) 2025 "YooMoney", NBСO LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

namespace YooKassa\Common\Exceptions;

class InvalidPropertyValueTypeException extends InvalidPropertyException
{
    /**
     * @var string
     */
    private $type;

    /**
     * InvalidPropertyValueTypeException constructor.
     * @param string $message
     * @param int $code
     * @param string $property
     * @param mixed $value
     */
    public function __construct($message = "", $code = 0, $property = "", $value = null)
    {
        parent::__construct($message, $code, $property);
        if ($value === null) {
            $this->type = 'null';
        } elseif (is_object($value)) {
            $this->type = get_class($value);
        } else {
            $this->type = gettype($value);
        }
    }

    /**
     * @return string
     */
    public function getType()
    {
        return $this->type;
    }
}
